@@ -1,4 +1,4 @@
-# Copyright (c) 2011 Riverbank Computing Limited <info@riverbankcomputing.com>
+# Copyright (c) 2012 Riverbank Computing Limited <info@riverbankcomputing.com>
 # 
 # This file is part of PyQt.
 # 
@@ -14,13 +14,8 @@
 # GPL Exception version 1.1, which can be found in the file
 # GPL_EXCEPTION.txt in this package.
 # 
-# Please review the following information to ensure GNU General
-# Public Licensing requirements will be met:
-# http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-# you are unsure which license is appropriate for your use, please
-# review the following information:
-# http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-# or contact the sales department at sales@riverbankcomputing.com.
+# If you are unsure which license is appropriate for your use, please
+# contact the sales department at sales@riverbankcomputing.com.
 # 
 # This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 # WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -35,13 +30,13 @@ import sipconfig
 # These are installation specific values created when PyQt4 was configured.
 _pkg_config = {
     'pyqt_bin_dir':      '/usr/local/bin',
-    'pyqt_config_args':  '--verbose --qmake=/usr/local/bin/qmake4 --bindir=/usr/local/bin --destdir=/usr/local/lib/python2.7/site-packages --sipdir=/usr/local/share/sip --vendorid-incdir=/usr/local/include/python2.7 --vendorid-libdir=/usr/local/lib/python2.7 --no-qsci-api INCDIR_QT=/usr/local/include/X11/qt4 LIBDIR=/usr/X11R6/lib /usr/local/lib LIBDIR_QT=/usr/local/lib/qt4 CC=cc CXX=c++ CFLAGS=-O2 -pipe  CXXFLAGS=-O2 -pipe  --enable=QtCore --enable=QtGui --enable=QtNetwork --enable=QtOpenGL --enable=QtScript --enable=QtSql --enable=QtSvg --enable=QtTest --enable=QtXml --enable=QtAssistant --enable=QtDesigner --enable=QtWebKit --enable=QtHelp',
+    'pyqt_config_args':  '--verbose --qmake=/usr/local/bin/qmake4 --bindir=/usr/local/bin --destdir=/usr/local/lib/python2.7/site-packages --sipdir=/usr/local/share/sip --vendorid-incdir=/usr/local/include/python2.7 --vendorid-libdir=/usr/local/lib/python2.7 --no-qsci-api INCDIR_QT=/usr/local/include/X11/qt4 LIBDIR=/usr/X11R6/lib /usr/local/lib LIBDIR_QT=/usr/local/lib/qt4 CC=cc CXX=c++ CFLAGS=-O2 -pipe  CXXFLAGS=-O2 -pipe  --enable=QtAssistant --enable=QtCore --enable=QtDBus --enable=QtDeclarative --enable=QtDesigner --enable=QtGui --enable=QtHelp --enable=QtMultimedia --enable=QtNetwork --enable=QtOpenGL --enable=QtScript --enable=QtScriptTools --enable=QtSql --enable=QtSvg --enable=QtTest --enable=QtWebKit --enable=QtXml --enable=QtXmlPatterns --enable=phonon',
     'pyqt_mod_dir':      '/usr/local/lib/python2.7/site-packages/PyQt4',
-    'pyqt_modules':      'QtCore QtGui QtHelp QtNetwork QtOpenGL QtScript QtSql QtSvg QtTest QtWebKit QtXml QtDesigner',
+    'pyqt_modules':      'QtCore QtGui QtHelp QtMultimedia QtNetwork QtDBus QtDeclarative QtOpenGL QtScript QtScriptTools QtSql QtSvg QtTest QtWebKit QtXml QtXmlPatterns phonon QtDesigner',
     'pyqt_sip_dir':      '/usr/local/share/sip',
-    'pyqt_sip_flags':    '-x VendorID -t WS_X11 -x PyQt_NoPrintRangeBug -t Qt_4_7_2 -x Py_v3 -g',
-    'pyqt_version':      0x040804,
-    'pyqt_version_str':  '4.8.4',
+    'pyqt_sip_flags':    '-x VendorID -t WS_X11 -x PyQt_NoPrintRangeBug -t Qt_4_8_0 -x Py_v3 -g',
+    'pyqt_version':      0x040905,
+    'pyqt_version_str':  '4.9.5',
     'qt_data_dir':       '/usr/local/lib/qt4',
     'qt_dir':            '/usr/local/lib/qt4',
     'qt_edition':        'free',
@@ -49,7 +44,7 @@ _pkg_config = {
     'qt_inc_dir':        '/usr/local/include/X11/qt4',
     'qt_lib_dir':        '/usr/local/lib/qt4',
     'qt_threaded':       1,
-    'qt_version':        0x040703,
+    'qt_version':        0x040802,
     'qt_winconfig':      'shared'
 }
 
@@ -58,6 +53,7 @@ _default_macros = {
     'AR':                       'ar q',
     'CC':                       'cc',
     'CFLAGS':                   '-O2 -pipe ',
+    'CFLAGS_APP':               '',
     'CFLAGS_CONSOLE':           '',
     'CFLAGS_DEBUG':             '-g',
     'CFLAGS_EXCEPTIONS_OFF':    '',
@@ -76,10 +72,11 @@ _default_macros = {
     'CFLAGS_WARN_OFF':          '-w',
     'CFLAGS_WARN_ON':           '-Wall -W',
     'CHK_DIR_EXISTS':           'test -d',
-    'CONFIG':                   'qt warn_on release link_prl',
+    'CONFIG':                   'qt warn_on release link_prl gdb_dwarf_index',
     'COPY':                     'cp -f',
     'CXX':                      'c++',
     'CXXFLAGS':                 '-O2 -pipe ',
+    'CXXFLAGS_APP':             '',
     'CXXFLAGS_CONSOLE':         '',
     'CXXFLAGS_DEBUG':           '-g',
     'CXXFLAGS_EXCEPTIONS_OFF':  '',
@@ -129,7 +126,7 @@ _default_macros = {
     'LIBS_CORE':                '',
     'LIBS_GUI':                 '',
     'LIBS_NETWORK':             '',
-    'LIBS_OPENGL':              '-lGLU -lGL',
+    'LIBS_OPENGL':              '-lGL',
     'LIBS_RT':                  '',
     'LIBS_RTMT':                '',
     'LIBS_THREAD':              '',
@@ -395,3 +392,15 @@ class QAxContainerModuleMakefile(QtGuiModuleMakefile):
             kw["qt"] = ["QtCore", "QtGui", "QAxContainer"]
 
         QtGuiModuleMakefile.__init__(self, *args, **kw)
+
+
+class QtDBusModuleMakefile(QtCoreModuleMakefile):
+    """The Makefile class for modules that %Import QtDBus.
+    """
+    def __init__(self, *args, **kw):
+        """Initialise an instance of a module Makefile.
+        """
+        if "qt" not in kw:
+            kw["qt"] = ["QtCore", "QtDBus"]
+
+        QtCoreModuleMakefile.__init__(self, *args, **kw)
